diff OrthancServer/OrthancInitialization.h @ 62:a70bb32802ae orthanc-renaming

renaming Server
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:33:19 +0200
parents 6da7fc87efaa
children fe180eae201d
line wrap: on
line diff
--- a/OrthancServer/OrthancInitialization.h	Sun Sep 16 09:30:31 2012 +0200
+++ b/OrthancServer/OrthancInitialization.h	Sun Sep 16 09:33:19 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,11 +25,11 @@
 #include <json/json.h>
 #include "../Core/HttpServer/MongooseServer.h"
 
-namespace Palanthir
+namespace Orthanc
 {
-  void PalanthirInitialize(const char* configurationFile = NULL);
+  void OrthancInitialize(const char* configurationFile = NULL);
 
-  void PalanthirFinalize();
+  void OrthancFinalize();
 
   std::string GetGlobalStringParameter(const std::string& parameter,
                                        const std::string& defaultValue);
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium